@@ -14,16 +14,24 @@ def get_stream():
 def test_ACS_Prequential():
     "Bare ACS for Prequential"
     stream = get_stream()
-    clf = sl.classifiers.AccumulatedSamplesClassifier()
+    clf = sl.classifiers.ASC(base_clf=GaussianNB())
     evaluator = sl.evaluators.Prequential()
     evaluator.process(stream, clf)
 
 
+def test_ACS_fit_and_proba():
+    "Bare ACS for Prequential"
+    stream = get_stream()
+    X, y = stream.get_chunk()
+    clf = sl.classifiers.ASC(base_clf=GaussianNB())
+    clf.fit(X, y)
+    proba = clf.predict_proba(X)
+
+
 def test_MetaEstimator_TestThanTrain():
     "Bare ACS for TTT"
     stream = get_stream()
-    base = sl.classifiers.SampleWeightedMetaEstimator(
-        base_classifier=GaussianNB())
+    base = sl.classifiers.SampleWeightedMetaEstimator(base_classifier=GaussianNB())
     clf = sl.ensembles.OOB(base_estimator=base)
     evaluator = sl.evaluators.TestThenTrain()
     evaluator.process(stream, clf)
@@ -33,7 +41,6 @@ def test_MetaEstimator_fit():
     "Bare ACS for TTT"
     stream = get_stream()
     X, y = stream.get_chunk()
-    clf = sl.classifiers.SampleWeightedMetaEstimator(
-        base_classifier=GaussianNB())
+    clf = sl.classifiers.SampleWeightedMetaEstimator(base_classifier=GaussianNB())
     clf.fit(X, y)
     clf.predict(X)
