@@ -4,6 +4,7 @@ import sys
 
 from sklearn.naive_bayes import GaussianNB
 
+import numpy as np
 import pytest
 import strlearn as sl
 
@@ -15,6 +16,11 @@ def get_stream():
 def get_different_stream():
     return sl.streams.StreamGenerator(n_chunks=10, n_features=4)
 
+def test_DWM():
+    stream = get_stream()
+    evaluator = sl.evaluators.TestThenTrain()
+    evaluator.process(stream, sl.ensembles.DWM(GaussianNB(), p=stream.chunk_size))
+
 
 def test_AWE():
     stream = get_stream()
@@ -22,7 +28,22 @@ def test_AWE():
     evaluator.process(stream, sl.ensembles.AWE(GaussianNB(), n_estimators=5))
 
 
-def test_AWE():
+def test_pp():
+    stream = get_stream()
+    clf = sl.ensembles.SEA(GaussianNB())
+
+    X, y = stream.get_chunk()
+
+    clf.partial_fit(X, y)
+
+    pp = clf.predict_proba(X)
+    y_pred = clf.predict(X)
+    y_pred_pp = np.argmax(pp, axis=1)
+
+    assert np.array_equal(y_pred, y_pred_pp)
+
+
+def test_AUE():
     stream = get_stream()
     evaluator = sl.evaluators.TestThenTrain()
     evaluator.process(stream, sl.ensembles.AUE(GaussianNB(), n_estimators=5))
@@ -35,8 +56,10 @@ def test_ensembles_fit():
     clf4 = sl.ensembles.OnlineBagging(GaussianNB())
     clf5 = sl.ensembles.UOB(GaussianNB())
     clf6 = sl.ensembles.AWE(GaussianNB())
+    clf7 = sl.ensembles.AUE(GaussianNB())
+    clf8 = sl.ensembles.DWM(GaussianNB())
 
-    clfs = (clf1, clf2, clf3, clf4, clf5, clf6)
+    clfs = (clf1, clf2, clf3, clf4, clf5, clf6, clf7, clf8)
 
     stream = get_stream()
     X, y = stream.get_chunk()
@@ -55,6 +78,8 @@ def test_features():
         sl.ensembles.UOB(GaussianNB()),
         sl.ensembles.WAE(GaussianNB()),
         sl.ensembles.AWE(GaussianNB()),
+        sl.ensembles.AUE(GaussianNB()),
+        sl.ensembles.DWM(GaussianNB()),
         sl.ensembles.OnlineBagging(GaussianNB()),
     ]
     stream = get_stream()
@@ -77,6 +102,8 @@ def test_pred():
         sl.ensembles.UOB(GaussianNB()),
         sl.ensembles.WAE(GaussianNB()),
         sl.ensembles.AWE(GaussianNB()),
+        sl.ensembles.AUE(GaussianNB()),
+        sl.ensembles.DWM(GaussianNB()),
         sl.ensembles.OnlineBagging(GaussianNB()),
     ]
     stream = get_stream()
